const Main = imports.ui.main;
const Mainloop = imports.mainloop;

const St = imports.gi.St;
const Lang = imports.lang;
const PanelMenu = imports.ui.panelMenu;
const Clutter = imports.gi.Clutter;
const GLib = imports.gi.GLib;
const ShellToolkit = imports.gi.St;

function _get_access_point_name() {
  var command_output_bytes = GLib.spawn_command_line_sync('iwgetid -r')[1];
  var command_output_string = '';

  for (
    var current_character_index = 0;
    current_character_index < command_output_bytes.length;
    ++current_character_index
  ) {
    var current_character = String.fromCharCode(
      command_output_bytes[current_character_index]
    );
    command_output_string += current_character;
  }

  return command_output_string;
}

const AccessPointNameIndicator = new Lang.Class({
  Name: 'AccessPointName.indicator',
  Extends: PanelMenu.Button,

  _init: function () {
    this.parent(0.0, 'Access Point Name Indicator', false);
    this.buttonText = new St.Label({
      text: 'Loading...',
      y_align: Clutter.ActorAlign.CENTER,
    });
    this.actor.add_child(this.buttonText);
    this._updateLabel();
  },

  _updateLabel: function () {
    const refreshTime = 5; // in seconds

    if (this._timeout) {
      Mainloop.source_remove(this._timeout);
      this._timeout = null;
    }
    this._timeout = Mainloop.timeout_add_seconds(
      refreshTime,
      Lang.bind(this, this._updateLabel)
    );

    this.buttonText.set_text('[' + _get_access_point_name() + ']');
  },

  _removeTimeout: function () {
    if (this._timeout) {
      this._timeout = null;
    }
  },

  stop: function () {
    if (this._timeout) {
      Mainloop.source_remove(this._timeout);
    }
    this._timeout = undefined;

    this.menu.removeAll();
  },
});

let _indicator;

function init() {
  log('Access Point Name extension initialized');
}

function enable() {
  log('Access Point Name extension enabled');
  _indicator = new AccessPointNameIndicator();
  Main.panel.addToStatusArea('access-point-name-indicator', _indicator);
}

function disable() {
  log('Access Point Name extension disabled');
  _indicator.stop();
  _indicator.destroy();
}
